Scene Annotations
=================

.. autoclass:: yt_idv.scene_annotations.base_annotation.SceneAnnotation

.. autoclass:: yt_idv.scene_annotations.block_outline.BlockOutline

.. autoclass:: yt_idv.scene_annotations.box.BoxAnnotation

.. autoclass:: yt_idv.scene_annotations.text.TextAnnotation

